@@ -19,7 +19,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
  *********************************************************************/
 
@@ -30,7 +30,7 @@ using namespace std;
 
 #include "ticsOpData.h"
 #include "gnuInterface.h"
-#include <iostream.h>
+#include <iostream>
 #include <qstring.h>
 
 class ticsOp : public ticsOpData
