@@ -24,8 +24,10 @@ class KileAppDCOPIface : virtual public DCOPObject
   K_DCOP
 
   k_dcop:
-    virtual void load( const QString &f )=0;
+    virtual void fileSelected(const QString &url)=0;
+    virtual void projectOpen(const QString &url)=0;
     virtual void setLine( const QString &line )=0;
+    virtual void setActive()=0;
 };
 
 #endif
