@@ -19,13 +19,13 @@
 #define MESSAGEWIDGET_H
 
 #include <qwidget.h>
-#include <qtextedit.h>
+#include <ktextedit.h>
 
 /**
   *@author Pascal Brachet
   */
 
-class MessageWidget : public QTextEdit  {
+class MessageWidget : public KTextEdit  {
    Q_OBJECT
 public: 
 	MessageWidget(QWidget *parent, const char *name=0);
@@ -33,7 +33,9 @@ public:
 
 public slots:
    void highlight();
-   void insertLine(QString l);
+   void insertLine(const QString &l);
+   void insertAt(const QString &l, int para, int index);
+   void append(const QString &l);
 };
 
 #endif
